@ECHO OFF
REM MQE.SetOAM.bat                             CACI, Inc.    2014.01     G Brown
::
:: NOTE: This script normally should be invoked only by 'UpdateQMgr.bat'.
::
::
:: Typically all queue managers will have OAM mediated security set on
:: all queue manager system objects to control access and administrative
:: privileges for MQE (MQ Explorer) users.
::
:: MQE users typically fall into one of two classes: administrators (who by
:: default can do everything the group 'mqm' can do) and non-administrators
:: (who can only view the status and attribute values of queue manager objects).
::
:: Non-administrative users of MQE (MQ Explorer) are granted channel
:: access as MCA user 'mqe_usr' and collectively should be controlled
:: by restricting the IP address to those hosts from which MQE will
:: be running.
::
:: Administrative users of MQE are granted channel access as MCA user
:: 'mqa_usr' and must be granted such access on an individual user basis.
::
::

SET QMGR=%1
SET DOMAIN=%2
SET "MQA=%~3"
SET "MQE=%~4"

IF "%MQA%" == "" SET MQA=mqa
IF "%MQE%" == "" SET MQE=mqe

ECHO.
ECHO Updating the OAM to grant the group '%MQA%' authority to administer all WMQ objects on queue manager '%QMGR%'.

ECHO.
ECHO    setmqaut -m %QMGR%       -t qmgr     -g "%DOMAIN%\%MQA%" +all
        setmqaut -m %QMGR%       -t qmgr     -g "%DOMAIN%\%MQA%" +all      2>&1
ECHO.
ECHO    setmqaut -m %QMGR% -n ** -t authinfo -g "%DOMAIN%\%MQA%" +all +crt
        setmqaut -m %QMGR% -n ** -t authinfo -g "%DOMAIN%\%MQA%" +all +crt 2>&1
ECHO.
ECHO    setmqaut -m %QMGR% -n ** -t channel  -g "%DOMAIN%\%MQA%" +all +crt
        setmqaut -m %QMGR% -n ** -t channel  -g "%DOMAIN%\%MQA%" +all +crt 2>&1
ECHO.
ECHO    setmqaut -m %QMGR% -n ** -t clntconn -g "%DOMAIN%\%MQA%" +all +crt
        setmqaut -m %QMGR% -n ** -t clntconn -g "%DOMAIN%\%MQA%" +all +crt 2>&1
ECHO.
ECHO    setmqaut -m %QMGR% -n ** -t comminfo -g "%DOMAIN%\%MQA%" +all +crt
        setmqaut -m %QMGR% -n ** -t comminfo -g "%DOMAIN%\%MQA%" +all +crt 2>&1
ECHO.
ECHO    setmqaut -m %QMGR% -n ** -t listener -g "%DOMAIN%\%MQA%" +all +crt
        setmqaut -m %QMGR% -n ** -t listener -g "%DOMAIN%\%MQA%" +all +crt 2>&1
ECHO.
ECHO    setmqaut -m %QMGR% -n ** -t namelist -g "%DOMAIN%\%MQA%" +all +crt
        setmqaut -m %QMGR% -n ** -t namelist -g "%DOMAIN%\%MQA%" +all +crt 2>&1
ECHO.
ECHO    setmqaut -m %QMGR% -n ** -t process  -g "%DOMAIN%\%MQA%" +all +crt
        setmqaut -m %QMGR% -n ** -t process  -g "%DOMAIN%\%MQA%" +all +crt 2>&1
ECHO.
ECHO    setmqaut -m %QMGR% -n ** -t queue    -g "%DOMAIN%\%MQA%" +all +crt
        setmqaut -m %QMGR% -n ** -t queue    -g "%DOMAIN%\%MQA%" +all +crt 2>&1
ECHO.
ECHO    setmqaut -m %QMGR% -n ** -t rqmname  -g "%DOMAIN%\%MQA%" +all
        setmqaut -m %QMGR% -n ** -t rqmname  -g "%DOMAIN%\%MQA%" +all      2>&1
ECHO.
ECHO    setmqaut -m %QMGR% -n ** -t service  -g "%DOMAIN%\%MQA%" +all +crt
        setmqaut -m %QMGR% -n ** -t service  -g "%DOMAIN%\%MQA%" +all +crt 2>&1
ECHO.
ECHO    setmqaut -m %QMGR% -n ** -t topic    -g "%DOMAIN%\%MQA%" +all +crt
        setmqaut -m %QMGR% -n ** -t topic    -g "%DOMAIN%\%MQA%" +all +crt 2>&1
ECHO.
ECHO.


ECHO Updating the OAM to grant the group '%MQE%' read-only access to all WMQ objects on queue manager '%QMGR%'.

ECHO.
ECHO    setmqaut -m %QMGR%       -t qmgr     -g "%DOMAIN%\%MQE%" -all +connect +dsp +allmqi
        setmqaut -m %QMGR%       -t qmgr     -g "%DOMAIN%\%MQE%" -all +connect +dsp +allmqi 2>&1
ECHO.
ECHO    setmqaut -m %QMGR% -n ** -t queue    -g "%DOMAIN%\%MQE%" -all +dsp +allmqi
        setmqaut -m %QMGR% -n ** -t queue    -g "%DOMAIN%\%MQE%" -all +dsp +allmqi 2>&1
ECHO.
ECHO    setmqaut -m %QMGR% -n ** -t authinfo -g "%DOMAIN%\%MQE%" -all +dsp +inq
        setmqaut -m %QMGR% -n ** -t authinfo -g "%DOMAIN%\%MQE%" -all +dsp +inq 2>&1
ECHO.
ECHO    setmqaut -m %QMGR% -n ** -t namelist -g "%DOMAIN%\%MQE%" -all +dsp +inq
        setmqaut -m %QMGR% -n ** -t namelist -g "%DOMAIN%\%MQE%" -all +dsp +inq 2>&1
ECHO.
ECHO    setmqaut -m %QMGR% -n ** -t process  -g "%DOMAIN%\%MQE%" -all +dsp +inq
        setmqaut -m %QMGR% -n ** -t process  -g "%DOMAIN%\%MQE%" -all +dsp +inq 2>&1
ECHO.
ECHO    setmqaut -m %QMGR% -n ** -t channel  -g "%DOMAIN%\%MQE%" -all +dsp
        setmqaut -m %QMGR% -n ** -t channel  -g "%DOMAIN%\%MQE%" -all +dsp 2>&1
ECHO.
ECHO    setmqaut -m %QMGR% -n ** -t clntconn -g "%DOMAIN%\%MQE%" -all +dsp
        setmqaut -m %QMGR% -n ** -t clntconn -g "%DOMAIN%\%MQE%" -all +dsp 2>&1
ECHO.
ECHO    setmqaut -m %QMGR% -n ** -t comminfo -g "%DOMAIN%\%MQE%" -all +dsp
        setmqaut -m %QMGR% -n ** -t comminfo -g "%DOMAIN%\%MQE%" -all +dsp 2>&1
ECHO.
ECHO    setmqaut -m %QMGR% -n ** -t listener -g "%DOMAIN%\%MQE%" -all +dsp
        setmqaut -m %QMGR% -n ** -t listener -g "%DOMAIN%\%MQE%" -all +dsp 2>&1
ECHO.
ECHO    setmqaut -m %QMGR% -n ** -t rqmname  -g "%DOMAIN%\%MQE%" -all
        setmqaut -m %QMGR% -n ** -t rqmname  -g "%DOMAIN%\%MQE%" -all      2>&1
ECHO.
ECHO    setmqaut -m %QMGR% -n ** -t service  -g "%DOMAIN%\%MQE%" -all +dsp
        setmqaut -m %QMGR% -n ** -t service  -g "%DOMAIN%\%MQE%" -all +dsp 2>&1
ECHO.
ECHO    setmqaut -m %QMGR% -n ** -t topic    -g "%DOMAIN%\%MQE%" -all +dsp
        setmqaut -m %QMGR% -n ** -t topic    -g "%DOMAIN%\%MQE%" -all +dsp 2>&1
ECHO.

ECHO    setmqaut -m %QMGR% -n %QMGR%.DLQ                    -t queue -g "%DOMAIN%\%MQE%" -all +dsp +inq +browse
        setmqaut -m %QMGR% -n %QMGR%.DLQ                    -t queue -g "%DOMAIN%\%MQE%" -all +dsp +inq +browse 2>&1
ECHO.
ECHO    setmqaut -m %QMGR% -n SYSTEM.**                     -t queue -g "%DOMAIN%\%MQE%" -all +dsp +inq +browse
        setmqaut -m %QMGR% -n SYSTEM.**                     -t queue -g "%DOMAIN%\%MQE%" -all +dsp +inq +browse 2>&1
ECHO.
ECHO    setmqaut -m %QMGR% -n SYSTEM.ADMIN.COMMAND.QUEUE    -t queue -g "%DOMAIN%\%MQE%" -all +dsp +inq +put
        setmqaut -m %QMGR% -n SYSTEM.ADMIN.COMMAND.QUEUE    -t queue -g "%DOMAIN%\%MQE%" -all +dsp +inq +put 2>&1
ECHO.
ECHO    setmqaut -m %QMGR% -n SYSTEM.MQEXPLORER.REPLY.MODEL -t queue -g "%DOMAIN%\%MQE%" -all +dsp +inq +put +get
        setmqaut -m %QMGR% -n SYSTEM.MQEXPLORER.REPLY.MODEL -t queue -g "%DOMAIN%\%MQE%" -all +dsp +inq +put +get 2>&1
ECHO.
ECHO.

:: By default IBM MQ starts all cluster channels, but...
:: Our secured cluster channels should be stopped to prevent interminable
:: retries for lack of credentials or other security object / protocol.

ECHO. & ECHO Stopping secured channels...

FOR /F "delims=() skip=6 tokens=2,3*" %%A IN ('ECHO DISPLAY CHANNEL^(F_^*^) ^| runmqsc %QMGR%') DO (
  ECHO. & ECHO Stopping channel %%A & ECHO.
  ECHO STOP CHANNEL^(%%A^) STATUS^(STOPPED^) | runmqsc %QMGR%
)

ECHO. & ECHO Done! & ECHO.
